 %------------------------------------------------------------------
 %    Equilibrage Harmonique     
 %    
 %    La function Q est generique, elle est la meme pour tous
 %    les systemes traites
 
 function [Q] = Q(obj,U,V,H,Neq)
 
  H=obj.H;                                           % nombre d'harmoniques
  Neq=obj.Neq;                                         % nombre d'equations
  
  Gamma=1;
  
  indc=[Neq+1  :2*Neq:Neq*(2*H-1)+1];     % index des petits vecteurs  uic 
  inds=[2*Neq+1:2*Neq:Neq*(2*H)+1  ];     % index des petits vecteurs  uis 

  
  Q=zeros(Neq*(2*H+1),1);
  
  %------------------------------------------------------------------------------ 
  %   ---      equations issues de l'Equilibrage harmonique           ---
  %------------------------------------------------------------------------------

  % traitement des termes quadratiques Q(U,V)   lambda.D(U) et omega M(U)
  %----------------------------------------------------------------------
  
  % Harmonique zero
   SOM=zeros(Neq,1);
   for j=1:H
      SOM=SOM+pQ(U(indc(j):indc(j)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)  ...
             +pQ(U(inds(j):inds(j)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);
   end
   Q(1:Neq)= 0.5*SOM + pQ(U(1:Neq),V(1:Neq),Gamma) ;     ...      %   Q(U,V)
                    
  
  % Harmoniques suivantes 1,2,3, ...
  for ih=1:H   
     SOMC=zeros(Neq,1);
     SOMS=zeros(Neq,1);
     
     % les termes en +
     
        for j=1:ih-1
          SOMC=SOMC+pQ(U(indc(ih-j):indc(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)  ...
                   -pQ(U(inds(ih-j):inds(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);
          
          SOMS=SOMS+pQ(U(indc(ih-j):indc(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma)  ...
                   +pQ(U(inds(ih-j):inds(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma);
        end
     
     %les termes en -
   
         for j=ih+1:H
            SOMC=SOMC+pQ(U(indc(j):indc(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1),Gamma)     ...
                     +pQ(U(inds(j):inds(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1),Gamma)     ...   
                                                                                      ...
                     +pQ(U(indc(j-ih):indc(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)     ...
                     +pQ(U(inds(j-ih):inds(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);
                 
            SOMS=SOMS+pQ(U(inds(j):inds(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1),Gamma)     ...
                     -pQ(U(indc(j):indc(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1),Gamma)     ...   
                                                                                      ...
                     -pQ(U(inds(j-ih):inds(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)     ...
                     +pQ(U(indc(j-ih):indc(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);                           
                     
         end   
       %les termes courants
         Q(indc(ih):indc(ih)+Neq-1)=0.5*SOMC + pQ(U(indc(ih):indc(ih)+Neq-1),V(1:Neq),Gamma)   ...      % Q(U,V)
                                             + pQ(U(1:Neq),V(indc(ih):indc(ih)+Neq-1),Gamma)    ...     %
                                             - ih*V(Neq*(2*H+1)+1)*pM(U(inds(ih):inds(ih)+Neq-1)) ; % - lambda.M(U)
                                             
                                             
         Q(inds(ih):inds(ih)+Neq-1)=0.5*SOMS + pQ(U(inds(ih):inds(ih)+Neq-1),V(1:Neq),Gamma)   ...      % Q(U,V)
                                             + pQ(U(1:Neq),V(inds(ih):inds(ih)+Neq-1),Gamma)    ...     %         
                                             + ih*V(Neq*(2*H+1)+1)*pM(U(indc(ih):indc(ih)+Neq-1));  % - lambda.M(U)
   end   
 
 end 
 
 %------------------------------------------------------------------
 %    
 %    Les fonctions pQ et pM sont specifiques au pb traite
 %    
 %    Oscillateur de Duffing
 
 function [pQ] = pQ(U,V,Gamma)

  pQ=zeros(3,1);
  
  pQ(2)= -Gamma*U(1)*V(3);
  pQ(3)= -U(1)*V(1);
  
 end
  
  function [pM] = pM(U)

  pM=zeros(3,1);
  
  pM(1)=U(1);
  pM(2)=U(2);
  
  end