% Quadratic big operator bQ(bU,bU)
% with harmonic balance automatic computation of bL(bU)
 
function [Q] = Q(obj,U,V,H,Neq)
 
% User parameters
% ---------------

Gamma = obj.Gamma;         % NL coefficient
  
% ==================================================================
% Harmonic balance automatic computation of bQ(bU,bU)
% which depends on pQ and pM 
%
% Modifies only the call to pQ and pM to include the user parameters
% Lines marked with <--
% ================================================================== 

indc=[Neq+1  :2*Neq:Neq*(2*H-1)+1];     % index of  uic 
inds=[2*Neq+1:2*Neq:Neq*(2*H)+1  ];     % index of  uis 

Q=zeros(Neq*(2*H+1)+1,1);
  
%     Q(U,V) depends on pQ(.,.)   lambda pL1(.) and  omega pM(.)
% Harmonic zero

SOM=zeros(Neq,1);
for j=1:H
  SOM=SOM+pQ(U(indc(j):indc(j)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)  ...
         +pQ(U(inds(j):inds(j)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);
end
Q(1:Neq)= 0.5*SOM + pQ(U(1:Neq),V(1:Neq),Gamma)  ...     %   Q(U,V)
                  + V(Neq*(2*H+1)+1)*pL1(U(1:Neq));      %  lambda.L1(U)
  
% Harmonics 1,2,3,...
for ih=1:H   
  SOMC=zeros(Neq,1);
  SOMS=zeros(Neq,1);
     
  % + terms 
  for j=1:ih-1
    SOMC=SOMC+pQ(U(indc(ih-j):indc(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)  ...
             -pQ(U(inds(ih-j):inds(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);
          
    SOMS=SOMS+pQ(U(indc(ih-j):indc(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma)  ...
             +pQ(U(inds(ih-j):inds(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma);
  end
     
  % - terms
  for j=ih+1:H
    SOMC=SOMC+pQ(U(indc(j):indc(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1),Gamma)     ...
	     +pQ(U(inds(j):inds(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1),Gamma)     ...
             +pQ(U(indc(j-ih):indc(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)     ...
             +pQ(U(inds(j-ih):inds(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);
                 
    SOMS=SOMS+pQ(U(inds(j):inds(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1),Gamma)     ...
             -pQ(U(indc(j):indc(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1),Gamma)     ...   
             -pQ(U(inds(j-ih):inds(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1),Gamma)     ...
             +pQ(U(indc(j-ih):indc(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1),Gamma);   
  end
  % other terms        
  Q(indc(ih):indc(ih)+Neq-1)=0.5*SOMC + pQ(U(indc(ih):indc(ih)+Neq-1),V(1:Neq),Gamma) ...     % Q(U,V)
                                      + pQ(U(1:Neq),V(indc(ih):indc(ih)+Neq-1),Gamma)    ...  %
                                      + V(Neq*(2*H+1)+1)*pL1(U(indc(ih):indc(ih)+Neq-1)) ...  %  lambda.L1(U)
                                      - ih*V(Neq*(2*H+1)+2)*pM(U(inds(ih):inds(ih)+Neq-1)) ;  %  - omega.M(U)
  
  Q(inds(ih):inds(ih)+Neq-1)=0.5*SOMS + pQ(U(inds(ih):inds(ih)+Neq-1),V(1:Neq),Gamma) ...         % Q(U,V)
                                      + pQ(U(1:Neq),V(inds(ih):inds(ih)+Neq-1),Gamma) ...        %
                                      + V(Neq*(2*H+1)+1)*pL1(U(inds(ih):inds(ih)+Neq-1)) ... %  lambda.L1(U)
                                      + ih*V(Neq*(2*H+1)+2)*pM(U(indc(ih):indc(ih)+Neq-1));   %  - omega.M(U)
end   
 
% Phase equation
Q(Neq*(2*H+1)+1)= 0 ; 
 
% =============================================================================

% ------------------------------------------
% Function pQ, specific to the given problem
% ------------------------------------------
 
function [pQ] = pQ(U,V,Gamma)

pQ=zeros(3,1);
  
pQ(2)= -Gamma*U(1)*V(3);
pQ(3)= -U(1)*V(1);
  
% ------------------------------------------
% Function pL1, specific to the given problem
% ------------------------------------------

function [pL1] = pL1(U)

pL1=zeros(3,1);

pL1(2)=-U(2);
  
% ------------------------------------------
% Function pM, specific to the given problem
% ------------------------------------------

function [pM] = pM(U)

pM=zeros(3,1);
  
pM(1:2)=U(1:2);
  
