% Linear big operator bL(bU)
% with harmonic balance automatic computation of bL(bU)
 
function [L] = L(obj,U)

% User parameters
% ---------------

H=obj.H;                            % Harmonics number
Neq=obj.Neq;                        % Number of equations
mu=obj.mu;                          % Twice the damping coefficient
ome0sq=obj.ome0sq;

% =============================================================================
% Harmonic balance automatic computation of bL(bU)
% which depends on pL0 
%
% Modifies only the call to pl0 to include the user parameters
% Lines marked with <--
% =============================================================================

indc= Neq+1:2*Neq:Neq*(2*H-1)+1;     % index of uic 
inds= 2*Neq+1:2*Neq:Neq*(2*H)+1;     % index of uis 

L=zeros(Neq*(2*H+1),1);
  
% L depends on pL

L(1:Neq)=pL(U(1:Neq),mu,ome0sq);  % <--
for i=1:H
  L(Neq+2*(i-1)*Neq+1:2*Neq+2*(i-1)*Neq)  =pL(U(indc(i):indc(i)+Neq-1),mu,ome0sq); % <--
  L(2*Neq+2*(i-1)*Neq+1:3*Neq+2*(i-1)*Neq)=pL(U(inds(i):inds(i)+Neq-1),mu,ome0sq); % <--
end
  
% no phase equation
% =============================================================================

% ------------------------------------------
% Function pl, specific to the given problem
% ------------------------------------------
 
function [pL] = pL(U,mu,ome0sq)

pL=zeros(4,1);
pL(1)=   U(2);       
pL(2)=  -mu*U(2) -ome0sq*U(1) ;  
pL(3)=  -U(3);
pL(4)=  -U(4);
  


  
