% Multiple scale solution of:
%
% ''q1 + 2 mu1 q1' + omega1^2 q1 + alpha1 q1q2 
% ''q2 + 2 mu2 q2' + omega2^2 q2 + alpha2 q1^2 = F2 cos Omega t
%
% omega2 = 2 omega1 + sigma1
% Omega = omega2 + sigma2
% Sigma2 = sigmin:pas:sigmax
%
% From Nayfeh, A. H. & Mook, D. T. "Nonlinear Oscillations", Wiley, 1979
%
% [Sigma2,A2st,A2inst,A2C,A1Cst,A1Cinst]=Om_omega2(omega1,sigmin,sigmax,pas,sigma1,mu1,mu2,F2,alpha1, alpha2)

function [Sigma2,A2st,A2inst,A2C,A1Cst,A1Cinst]=Om_omega2(omega1,sigmin,sigmax,pas,sigma1,mu1,mu2,F2,alpha1, alpha2)

Sigma2 = sigmin:pas:sigmax; 
omega2 = 2*omega1+sigma1;

Gamma1 =(2*omega1*omega2)/(alpha1*alpha2)*(2*mu1*mu2 - Sigma2.*(sigma1+Sigma2)); 
Gamma2 =(2*omega1*omega2)/(alpha1*alpha2)*(2*mu1*Sigma2 + mu2*(sigma1+Sigma2));
A2=F2/2/omega2./sqrt(Sigma2.^2+mu2.^2);
A2C=2*omega1/alpha1*sqrt((sigma1+Sigma2).^2+4*mu1^2);
A1Cinst = 2*sqrt(-Gamma1 - sqrt( F2^2/alpha2^2/4 - Gamma2.^2)); 
A1Cst = 2*sqrt(-Gamma1 + sqrt( F2^2/alpha2^2/4 - Gamma2.^2)); 

% Elimination des "ailes" des courbes couplees, qui sont complexes
I=find(imag(A1Cst)~=0);
A1Cst(I)=NaN*ones(size(I));
A1Cinst(I)=NaN*ones(size(I));
A2C(I)=NaN*ones(size(I));
% Elimination de la partie centrale de A1Cinst,  partie reelle
% nulle et partie imaginaire non-nulle
I=find(imag(A1Cinst)~=0);
A1Cinst(I(2:end-1))=NaN*ones(size(I(2:end-1))); % On garde
                                                % nanmoins les
                                                % deux points
                                                % extrmes  partie
                                                % relle nulle,
                                                % pour que ce soit
                                                % plus joli
A1Cinst=real(A1Cinst);

% Dtection de la partie de A2 qui est instable
I=find(A2-A2C>0);
A2inst=NaN*ones(size(A2));
A2st=A2;
A2st(I)=NaN*ones(size(I));
A2inst(I)=A2(I);

Omega=2*omega1+Sigma2;
pencolorML

figure(10)
plot(Omega/2,A2st,'--','linewidth',.5,'Color',Col(2,:))
plot(Omega/2,A2inst,':','linewidth',.5,'Color',Col(2,:))
plot(Omega/2,A2C,'--','linewidth',.5,'Color',Col(2,:))
plot(Omega/2,A1Cst,'--','linewidth',.5,'Color',Col(1,:))
plot(Omega/2,A1Cinst,':','linewidth',.5,'Color',Col(1,:))

