%--------------------------------------------------------------------------
%  periodic solutions of ROSSLER model by HBM with MANLAB
%  -------------------------------------------------------------------------
%
%   Model equation
%   --------------
%   x' = -y -z
%   y' = x + a*y
%   z' = b + z(x-lambda)
%
%  x(t), y(t), z(t) unknown functions.  a,b,c real parameters. 
%
% 
%    x'  =      -y -z
%    y'  =      x+a*y
%    z'  = b            -lambda*z     +z*x
%

%    With  Z(t) = [ x  y  z ]  (Neq=3) the system becomes
%  
%   -->   m(Z') = c0 +l0(Z) + lambda l1(Z) + q(Z,Z) 
%
%  
%  Harmonic balance
%  ----------------
%
%
%  Z(t) = Z0 + Z1c cos(omega t) + Z1s sin(omega t) + Z2c cos(2 Omega t) + Z2s sin(2 Omega t) + ... 
%              ...  + ZHc cos(H omega t) + ZHs sin(H omega t).
%
%  the balance of the harmonics leads to a large system of size  Neq*(2H+1)
%
%      C0    +     lambda C1 + L0(U)         + lambda L1(U) + Q(U,U) - omega M(U)= 0 
%                  
%
%     with    U=[Z0  Z1c Z1s  Z2c Z2s  ...  ZHs ]
%  
%
%  Final algebraic system for Manlab  bL0 + bL(bU) + bQ(bU,bU) =0 
%  --------------------------------------------------------------
%
%   bU = [ U , lambda, omega ]
%
%   bL0       = C0
%   bL(bu)    = L0(U) + lambda C1
%   bQ(bU,bU) = Q(U,U) + lambda L1(U) - omega M(U)
%
%
%--------------------------------------------------------------------------

 manlabinit; 
 

 % Starting point : standard regime ? 2T regime ? 4T regime ?
 regime = 'T';
 if strcmp(regime,'T')==1,
   H=10
   Neq=3;
   % The object is created 
   ML_problem  = ROSSLER(H,Neq);
   load ML_Ustart_T
 elseif strcmp(regime,'2T')==1,
   H=20;
   Neq=3;
   % The object is created 
   ML_problem  = ROSSLER(H,Neq);
   load ML_Ustart_2T
 elseif strcmp(regime,'4T')==1,
   H=40;
   Neq=3;
   % The object is created 
   ML_problem  = ROSSLER(H,Neq);
   load ML_Ustart_4T
 end;
 
ML_Ustart = ML_Uj;

% definition of a vector whose components are the index of the
% variables to be plotted (x,y)
ML_dispvars = [ (2*H+1)*Neq+1 Neq+1 ; (2*H+1)*Neq+1 Neq+4 ; (2*H+1)*Neq+1 Neq+7; (2*H+1)*Neq+1 Neq+10; (2*H+1)*Neq+1 Neq+13; (2*H+1)*Neq+1 Neq+16];   
                              
% global ML_pointdisplay;
% ML_pointdisplay=1;

manlabstart; 

