% ==================================
% Buckling of a clamped-clamped beam
% ==================================
%
% Model equations
% ---------------
%
% Pour tout k \in [1,...,K]
%
% omegak2 uk + epsilon N \sum_i \alpha_i^k ui = 0
% N = N0 + 0.5 \sum_i,j \alpha_i^j ui uj
%
% !ATTENTION! 
% \epsilon = 12, et le 1/2 n'est pas dans l'adimensionnement
% de N: N=ESw0^2/L^2 
% Donc il y a un 1/2 dans l'quation en N...
%
% Pour Manlab:
% ------------
%
% lambda=N0 (paramtre de continuation)
%
% Pour tout k \in [1,...,K]
%
% omegak2 uk   +  epsilon N \sum_i \alpha_i^k ui = 0
% lambda - N   +  0.5  \sum_i,j \alpha_i^j ui uj = 0       
%
% U=[u1 ... uK N lambda]';
%
% By O. Thomas, Cnam, Paris, oct. 2010, olivier.thomas@cnam.fr
% 
% ===============================================================

addpath('/home/thomas/Matlab/MANLAB/MANLAB-2.0-beta/SRC')


close all;
clear all;
clear classes;

% Initialisation de Manlab (variables globales)
% ---------------------------------------------

manlabinit;                
 
% Definition des constantes
% -------------------------

% Poutre  section rectangulaire \epsilon=12
epsil=12;
% Vecteur contenant les numros de modes  simuler
K=10;
kk=[1:K]';
disp(['Nb. modes transverse: ',num2str(K)])

% Vecteur contenant les pulsations propres
load MOD_enc_enc_flex.mat;
OMEG=mod.zer(kk).^2;

% Matrice contenant les coefs \alpha_{ij}
load ALPHA_enc_enc_flex.mat;
ALPHA=alpha.mat(kk,kk);
PHI=mod.phi(kk,:);
clear alpha

% Taille du vecteur solution U:
Nu=K+1+1;

% Numros des coordonnes modales  afficher (length(kkdisp<8))
kkdisp=[1:min([K 4])];

% Quelques variables d'environnement
% ----------------------------------

% creation d'un objet de type FLAMNDDL; passage des constantes 
ML_problem  = FLAMNDDL(OMEG,ALPHA,PHI,epsil);    

% Conditions initiales 
ML_Ustart   = [zeros(Nu-1,1) ; 0];   % condition initiales
% coordonnes  afficher (U(N+1) -> prcontrainte)
ML_dispvars = [Nu*ones(size(kkdisp')) kkdisp']; 
% Appelle la fonction disp.m  chaque continuation de branche
ML_pointdisplay = 1; 
ML_algostab = 1;

% Pour la stabilit
% -----------------

ML_stability = 1;

% Nombre de tronons par branche
ML_problem = set_nbptstroncon(ML_problem,10);
% Nombre de pas de temps par orbite pour le calcul de stabilite = nech*H
ML_problem = set_nech(ML_problem,100);  


% Informations pour le calcul de stabilit
% 
% ddlstab=[u1 ... uK N lambda];
% u1=U(1)
% ...
% uK=U(K)
% N=U(2*K+1)
% lambda=U(Nu)
% ML_varstab = [u1 ... uK N lambda H] si H = 0 (stabilite statique)
% ML_varstab = [u1 ... uK N lambda Omega H] si H \neq 0 (Stabilite harmonique balance)
ML_varstab = [1:(K+1) Nu 0];

% Lancement de Manlab
% -------------------

manlabstart;              