function [check,eigen,vectors] = stabF(sys,ddlstab,diaginfos,params,HH)


nbddl=diaginfos.nbddl;
nbddlstab=diaginfos.nbddlstab;
tolstab=params.tolstab;

nbptstroncon = length(ddlstab(:,1));

if HH == 0
    check = zeros(nbptstroncon,1);
    eigen = zeros(nbptstroncon,nbddl);
    vectors = zeros(nbptstroncon,nbddl*nbddl);
    
    for k=1:nbptstroncon
    
        DFX = J0(sys,ddlstab(k,:)) + JL(sys,ddlstab(k,:)) + JQ(sys,ddlstab(k,:),ddlstab(k,:));
        [V,D] = eig(DFX);
        alf = diag(D);
    
        if any((real(alf) > 0+tolstab))
            stab = 0;
        else
            stab = 1;
        end
    check(k,1) = stab;
    eigen(k,:) = alf';
    vectors(k,:) = reshape(V,nbddl*nbddl,1)';
    end
    
else

    check = zeros(nbptstroncon,1);
%     eigen = zeros(nbptstroncon,nbddl); % we'll take only the nbddl meaningful ones
    eigen = zeros(nbptstroncon,nbddl*(2*HH+1)); % all the alphas [debug]
    vectors = zeros(nbptstroncon,nbddl*nbddl*(2*HH+1)); % idem
    XX = reshape(ones(nbddl,1)*(-HH:HH),nbddl*(2*HH+1),1); % used for sorting
%
    for k=1:nbptstroncon
        
        omega=ddlstab(k,end);
        HILL = Hill_mat(sys, ddlstab(k,:), nbddlstab , nbddl, HH);

        [V,D] = eig(HILL);
        soluce = diag(D);

%%%% Sort the 'nbddl*(2H+1)' Floquet exponents and take the best 'nbddl' ones
        % chek for symetry of each eigenvector
        med = sum((repmat(XX,1,nbddl*(2*HH+1))).*(abs(V)),1)./sum(abs(V),1);
        % reorder from the most symetric to the least symetric eigenvector
        [val,ind] = sort(abs(med));


%%%% Sort again to avoid spurious PD detection
        test = 0;
        inc = 0;
        inc2T = zeros(1,nbddl);
        for hh = 1:nbddl
            inc = inc +1;
            if abs(abs(imag(soluce(ind(inc)))) - omega/2) < 1e-4
                test = test + 1;
                if test == 1
                    val0 = abs(sign(imag(soluce(ind(inc)))) + sign(real(soluce(ind(inc)))));
                    inc2T(hh) = ind(inc);
                elseif test == 2
                    val1 = abs(sign(imag(soluce(ind(inc:inc+2)))) + sign(real(soluce(ind(inc:inc+2))))) - val0;
                    indint = find(val1==0,1) - 1;
                    %[test Sami]
                    if ~isempty(indint)
                        inc2T(hh) = ind(inc+indint);
                        inc = inc+2;
                        test = 0;
                    else
                        inc2T(hh) = ind(inc+2);
                        inc=inc+2;
                        test=1;
                    end
                    %[test Sami]
                    
%                     inc2T(hh) = ind(inc+indint);
%                     inc = inc+2;
%                     test = 0;
                end
            else
                inc2T(hh) = ind(inc);
            end
        end
        %
        indorder = [inc2T setdiff(ind,inc2T)];
        alf = soluce(inc2T);
        vecconv = V(:,inc2T);

% % New test to avoid spurious PD and NS detection
% %         alfa=soluce(1:nbddl);
%         alfa=alf;
%         testreal=abs(imag(alfa))<omega/2/pi*1e-4;
%         [alfareal,indreal]=sort(alfa(testreal));
%         [alfacomplex,indcomplex]=sort(alfa(~testreal));
%         alf=[alfareal ; alfacomplex];
% %         vecreal=V(:,testreal);
%          vecreal=vecconv(:,testreal);
% %         veccomplex=V(:,~testreal);
%          veccomplex=vecconv(:,~testreal);
%          vectri=[vecreal(:,indreal) veccomplex(:,indcomplex)];
        
%%%% Test if there is any unstable Floquet multipliers
        rho=exp(alf*2*pi/ddlstab(k,end));
        if any((abs(rho) > 1+tolstab))
            stab = 0;
        else
            stab = 1;
        end
        
        check(k,1) = stab;
        eigen(k,:) = soluce(indorder)';
        vectors(k,:) = reshape(vecconv,nbddl*nbddl*(2*HH+1),1)';

% % use new algo for sorting alphas and vectors
%         eigen(k,:) = alf';
%         vectors(k,:) = reshape(vectri,1,nbddl*nbddl*(2*HH+1));
    end   
end

end

