% plotbranchbifXHBM   Branch plot for Manlab/HBM with user defined x axis.
%    Hand=plotbranchbifXYHBM(Nds,U,Ustab,X,Y,fig) plots vector Y as a
%    function of vector X with the stability state computed by 
%    the Manlab/HBM method.
%    It also displays the bifurcation points:
%    - B for a simple bifurcation (saddle-node, pitchfork...)
%    - PD for period doubling bifurcation
%    - NS for Neimark-Sacker bifurcation
%
%    U is the vector of unknowns of the final algebraic system solved
%    by Manlab and Ustab the stability data. 
% 
%    X and Y are vectors, with length(X)=length(Y)=size(U,2)
%
%    Idisp contains the indices of the entries of the initial physical 
%    unknown vector u(t) to be displayed and Hdisp the corresponding
%    harmonics number.
%
%    H is the number of harmonics of the simulation.
%
%    Neq is the number of equations of the initial system of unknown
%    u(t)
%
%    Nds is the initial dynamical system size (this is also the number
%    of Floquet multipliers)
%
%    fig is a figure/axis handle to plot the bargraph on.
%
%    It returns in Hand a column vector of handles to lineseries objects, 
%    one handle per plotted line.
%
%    By O. Thomas / Oct. 2010

function Hand=plotbranchbifXYHBM(Nds,U,Ustab,X,Y,fig)

pencolorML;
style = {':','-'};

% Activate axis
% =============

if floor(fig)==fig
  figure(fig)
  hold on
else
  axes(fig)
  hold on
end

% Plotting the branches
% =====================

%  0 1 1 1 1 1  1 0 0 0 0 0 0
%0 1 1 1 1 1 1  0 0 0 0 0 0
%  1 0 0 0 0 0 -1 0 0 0 0 0

Hand=[];
hold on

%omega = U(end,:);
%stab = Ustab(1,:);  
[Bbif,stab]=detectbifurcHBM(Nds,U,Ustab);
Ibif=[1 Bbif(1,:) size(U,2)];
Tbif=Bbif(2,:);

for bb=1:(length(Ibif)-1)
    II=Ibif(bb):Ibif(bb+1);
    st=style{stab(Ibif(bb)+1)+1};
    hand=plot(X(II),Y(II),st,'Color',Col(1,:),'linewidth',1);
    Hand=[Hand;hand];
end
hand=plot(X(Ibif(2:end-1)),Y(Ibif(2:end-1)),'.','Color',Col(1,:));
Hand=[Hand;hand];

for ib=1:size(Bbif,2)
    ibif=Bbif(1,ib);
    tbif=Bbif(2,ib);
    switch tbif
     case 1
      str='B';
     case 2
      str='PD';
     case 3
      str='NS';
    end
    text(X(ibif),Y(ibif),str,'margin',3,'verticalalignment','Bottom')
end
box on
  
  
